@@ -1,4 +1,4 @@
-# $Id: ContextI.pm,v 1.2 2001/12/06 23:03:39 markw Exp $
+# $Id: ContextI.pm,v 1.5 2002/03/06 23:28:52 dblock Exp $
 #
 # Genquire module for GQ::Server::ContextI
 #
@@ -76,12 +76,12 @@ use strict;
 use vars qw( @ISA $AUTOLOAD );  #Keep 'use strict' happy
 use Carp;
 
-# Object preamble - inherits from Bio::Root::RootI
+# Object preamble - inherits from Bio::Root::Root
 
-use Bio::Root::RootI;
+use Bio::Root::Root;
 
 
-@ISA = qw(Bio::Root::RootI );
+@ISA = qw(Bio::Root::Root);
 
 =head2 new
 
